## E1700 (yield-inside-async-function)

### :x: Problematic code:

```python
async def foo():
    yield 42
    yield from [1, 2, 3]
```

### :heavy_check_mark: Correct code:

```python
async def foo():
    def _inner_foo():
        yield 42
        yield from [1, 2, 3]
```

### Rationale:

Used when an `yield` or `yield from` statement is found inside an async
function. This message belongs to the async checker. It can't be emitted when
using Python < 3.5.

### Related resources:

- [Testcases](https://github.com/PyCQA/pylint/blob/master/tests/functional/y/yield_inside_async_function.py)
- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22yield-inside-async-function%22+OR+%22E1700%22)
