## C0123 (unidiomatic-typecheck)

### :x: Problematic code:

```python
foo = [1, 2, 3]
if type(foo) is list:
    pass
```

### :heavy_check_mark: Correct code:

```python
foo = [1, 2, 3]
if isinstance(foo, list):
    pass
```

### Rationale:

Using `type()` instead of `isinstance()` for a typecheck.
The idiomatic way to perform an explicit typecheck in Python is to use
`isinstance(x, y)` rather than `type(x) == Y`, `type(x) is Y`. Though there are
unusual situations where these give different results.

### Related resources:

- [Testcases](https://github.com/PyCQA/pylint/blob/master/tests/functional/u/unidiomatic_typecheck.py)
- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22unidiomatic-typecheck%22+OR+%22C0123%22)
