## E0101 (return-in-init)

### :x: Problematic code:

```python
class Foo:
    def __init__(self, value):
        return value
```

### :heavy_check_mark: Correct code:

```python
class Foo:
    def __init__(self, value):
        self.value = value


foo = Foo([1, 2, 3])
print(foo.value)
```

### Rationale:

Explicit return in `__init__`
Used when the special class method `__init__` has an explicit return value.
`__init__` magic method is a basically constructor of an instance, so it should
constuct it but not return anything. The rest can be achieved through object
attributes like method, property, etc.

### Related resources:

- [Testcases](https://github.com/PyCQA/pylint/blob/master/tests/functional/r/return_in_init.py)
- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22return-in-init%22+OR+%22E0101%22)
