## E0110 (abstract-class-instantiated)

### :x: Problematic code:

```python
from abc import ABC, abstractmethod


class BaseClass(ABC):
    @abstractmethod
    def get_something(self):
        pass


base = BaseClass()
```

### :heavy_check_mark: Correct code:

```python
from abc import ABC, abstractmethod


class BaseClass(ABC):
    @abstractmethod
    def get_something(self):
        pass


class Foo(BaseClass):
    def get_something(self):
        pass


foo = Foo()
```

### Rationale:

Used when an abstract class with `abc.ABCMeta` or `abc.ABC` as metaclass has
abstract methods and is instantiated.

### Related resources:

- [Testcases](https://github.com/PyCQA/pylint/blob/master/tests/functional/a/abstract_class_instantiated_py3.py)
- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22abstract-class-instantiated%22+OR+%22E0110%22)
