## E0115 (nonlocal-and-global)

### :x: Problematic code:

```python
MSG = 'Outside'


def foo():
    def bar():
        nonlocal MSG
        global MSG
        MSG = 'Inside'

    bar()
    print(MSG)
```

### :heavy_check_mark: Correct code:

```python
MSG = 'Outside'


def foo():
    global MSG
    MSG = 'Inside'
    msg = 'Outside'

    def bar():
        nonlocal msg
        msg = 'Inside'

    bar()
    print(MSG)
    print(msg)
```

### Rationale:

Emitted when a name is both `nonlocal` and `global`.

### Related resources:

- [Testcases](https://github.com/PyCQA/pylint/blob/master/tests/functional/n/nonlocal_and_global.py)
- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22nonlocal-and-global%22+OR+%22E0115%22)
