## E0116 (continue-in-finally)

### :x: Problematic code:

```python
while True:
    try:
        pass
    finally:
        continue
```

### :heavy_check_mark: Correct code:

```python
while True:
    try:
        pass
    except Exception:
        pass
    else:
        continue
```

### Rationale:

Emitted when the `continue` keyword is found inside a `finally` clause, which
is a `SyntaxError`.

### Related resources:

- [Testcases](https://github.com/PyCQA/pylint/blob/master/tests/functional/c/continue_in_finally.py)
- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22continue-in-finally%22+OR+%22E0116%22)
