## E0117 (nonlocal-without-binding)

### :x: Problematic code:

```python
def foo():
    def bar():
        nonlocal msg
        msg = 'Inside'

    bar()
    print(msg)
```

### :heavy_check_mark: Correct code:

```python
def foo():
    msg = 'Outside'

    def bar():
        nonlocal msg
        msg = 'Inside'

    bar()
    print(msg)
```

### Rationale:

Emitted when a `nonlocal` variable does not have an attached name somewhere in
the parent scopes.

### Related resources:

- [Testcases](https://github.com/PyCQA/pylint/blob/master/tests/functional/n/nonlocal_without_binding.py)
- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22nonlocal-without-binding%22+OR+%22E0117%22)
