## E0118 (used-prior-global-declaration)

### :x: Problematic code:

```python
MSG = 'Outside'


def foo():
    print(MSG)

    global MSG
    MSG = 'Inside'
    print(MSG)
```

### :heavy_check_mark: Correct code:

```python
MSG = 'Outside'


def foo():
    global MSG
    print(MSG)

    MSG = 'Inside'
    print(MSG)
```

### Rationale:

Emitted when a name is used prior a `global` declaration, which results in an
error since Python 3.6. It can't be emitted when using Python < 3.6.

### Related resources:

- [Testcases](https://github.com/PyCQA/pylint/blob/master/tests/functional/u/used_prior_global_declaration.py)
- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22used-prior-global-declaration%22+OR+%22E0118%22)
