## W0105 (pointless-string-statement)

### :x: Problematic code:

```console
$ cat >> system.py <<EOF
"""Module docstring."""

"system"
EOF
```

### :heavy_check_mark: Correct code:

```console
$ cat >> system.py <<EOF
"""Module docstring."""

value = "system"
EOF
```

### Rationale:

Used when a string is used as a statement (which of course has no effect).
This is a particular case of W0104 with its own message so you can easily
disable it if you're using those strings as documentation, instead of
comments.

### Related resources:

- [Testcases](https://github.com/PyCQA/pylint/blob/master/tests/functional/s/statement_without_effect.py)
- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22pointless-string-statement%22+OR+%22W0105%22)
