## C0203 (bad-mcs-method-argument)

### :x: Problematic code:

```python
class Meta(type):
    def __new__(some):
        pass
```

### :heavy_check_mark: Correct code:

```python
class Meta(type):
    def __new__(mcs):
        pass
```

### Rationale:

Used when a metaclass method has a first argument named differently than the
value specified in valid-classmethod-first-arg option (default to `cls`),
recommended to easily differentiate them from regular instance methods.

Weird enough but usually naming of the first argument is `mcs` and pylint
documentation says so but when someone specifies it then the lib throws
C0203 error.

### Related resources:

- [Testcases](https://github.com/PyCQA/pylint/blob/master/tests/input/func_first_arg.py)
- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22bad-mcs-method-argument%22+OR+%22C0203%22)
