## C0204 (bad-mcs-classmethod-argument)

### :x: Problematic code:

```python
class Meta(type):
    @classmethod
    def foo(some):
        pass
```

### :heavy_check_mark: Correct code:

```python
class Meta(type):
    @classmethod
    def foo(mcs):
        pass
```

### Rationale:

Used when a metaclass class method has a first argument named differently
than the value specified in valid-metaclass-classmethod-first-arg option
(default to `cls`), recommended to easily differentiate them from regular
instance methods.

Weird enough but usually naming of the first argument is `mcs` and pylint
documentation says so but when someone specifies it then the lib throws
C0204 error.

### Related resources:

- [Testcases](https://github.com/PyCQA/pylint/blob/master/tests/input/func_first_arg.py)
- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22bad-mcs-classmethod-argument%22+OR+%22C0204%22)
