## C0205 (single-string-used-for-slots)

### :x: Problematic code:

```python
class Foo:
    __slots__ = 'bar'

    def __init__(self, bar):
        self.bar = bar
        self.setup()

    def setup(self):
        pass
```

### :heavy_check_mark: Correct code:

```python
class Foo:
    __slots__ = ('bar',)

    def __init__(self, bar):
        self.bar = bar
        self.setup()

    def setup(self):
        pass
```

### Rationale:

Used when a class `__slots__` is a simple string, rather than an iterable.

### Related resources:

- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22single-string-used-for-slots%22+OR+%22C0205%22)
