## E0202 (method-hidden)

### :x: Problematic code:

```python
class Foo:
    def __init__(self, foo):
        if foo:
            self.foo = foo

    def foo(self):
        pass
```

### :heavy_check_mark: Correct code:

```python
class Foo:
    def __init__(self, bar):
        if bar:
            self.bar = bar

    def baz(self):
        pass
```

### Rationale:

Used when a class defines a method which is hidden by an instance attribute
from an ancestor class or set by some client code.

### Related resources:

- [Testcases](https://github.com/PyCQA/pylint/blob/master/tests/functional/m/method_hidden.py)
- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22method-hidden%22+OR+%22E0202%22)
