## E0236 (invalid-slots-object)

### :x: Problematic code:

```python
class Foo:
    __slots__ = ('bar', '')

    def __init__(self, bar):
        self.bar = bar
        self.setup()

    def setup(self):
        pass
```

### :heavy_check_mark: Correct code:

```python
class Foo:
    __slots__ = ('bar',)

    def __init__(self, bar):
        self.bar = bar
        self.setup()

    def setup(self):
        pass
```

### Rationale:

Used when an invalid (non-string) object occurs in `__slots__`.

### Related resources:

- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22invalid-slots-object%22+OR+%22E0236%22)
