## E0237 (assigning-non-slot)

### :x: Problematic code:

```python
class Foo:
    __slots__ = ('bar',)

    def __init__(self, bar, baz):
        self.bar = bar
        self.baz = baz
        self.setup()

    def setup(self):
        pass
```

### :heavy_check_mark: Correct code:

```python
class Foo:
    __slots__ = ('bar', 'baz')

    def __init__(self, bar, baz):
        self.bar = bar
        self.baz = baz
        self.setup()

    def setup(self):
        pass
```

### Rationale:

Used when assigning to an attribute not defined in the class slots.

### Related resources:

- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22assigning-non-slot%22+OR+%22E0237%22)
