## E0301 (non-iterator-returned)

### :x: Problematic code:

```python
class Iterator:
    def __init__(self, end, start=0):
        self.n = start
        self.end = end

    def __iter__(self):
        return self
```

### :heavy_check_mark: Correct code:

```python
class Iterator:
    def __init__(self, end, start=0):
        self.n = start
        self.end = end

    def __iter__(self):
        return self

    def __next__(self):
        if self.n <= self.end:
            n = self.n
            self.n += 1
            return n

        raise StopIteration
```

### Rationale:

Used when an `__iter__` method returns something which is not an iterable
(i.e. has no `__next__` method).

### Related resources:

- [Testcases](#)
- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22non-iterator-returned%22+OR+%22E0301%22)
