## E0302 (unexpected-special-method-signature)

### :x: Problematic code:

```python
class Foo:
    def __enter__(self, context):
        pass

    def __exit__(self, type):
        pass
```

### :heavy_check_mark: Correct code:

```python
class Foo:
    def __enter__(self):
        pass

    def __exit__(self, type, value, traceback):
        pass
```

### Rationale:

Emitted when a special method was defined with an invalid number of
parameters. If it has too few or too many, it might not work at all.

### Related resources:

- [Testcases](https://github.com/PyCQA/pylint/blob/master/tests/functional/u/unexpected_special_method_signature.py)
- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22unexpected-special-method-signature%22+OR+%22E0302%22)
