## W0221 (arguments-differ)

### :x: Problematic code:

```python
class Foo:
    def bar(self, arg):
        pass


class Baz(Foo):
    def bar(self, arg, arg2):
        pass
```

### :heavy_check_mark: Correct code:

```python
class Foo:
    def bar(self, arg):
        pass


class Baz:
    def __init__(self, intermediate):
        self.intermediate = intermediate

    def bar(self, arg):
        args = [arg, *self.intermediate]
        # do the rest
```

### Rationale:

Used when a method has a different number of arguments than in the
implemented interface or in an overridden method.

### Related resources:

- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22arguments-differ%22+OR+%22W0221%22)
