## W0231 (super-init-not-called)

### :x: Problematic code:

```python
class Foo:
    def __init__(self):
        self.foo = True


class Baz(Foo):
    def __init__(self):
        self.baz = True
```

### :heavy_check_mark: Correct code:

```python
class Foo:
    def __init__(self):
        self.foo = True


class Baz(Foo):
    def __init__(self):
        super().__init__()
        self.baz = True
```

### Rationale:

Used when an ancestor class method has an `__init__` method which is not
called by a derived class.

### Related resources:

- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22super-init-not-called%22+OR+%22W0231%22)
