## W0233 (non-parent-init-called)

### :x: Problematic code:

```python
class Foo:
    def __init__(self):
        self.foo = True


class Bar(Foo):
    def __init__(self):
        super().__init__()
        self.bar = True


class Baz(Bar):
    def __init__(self):
        Foo.__init__(self)
        self.baz = True

```

### :heavy_check_mark: Correct code:

```python
class Foo:
    def __init__(self):
        self.foo = True


class Bar:
    def __init__(self):
        super().__init__()
        self.bar = True


class Baz(Foo, Bar):
    def __init__(self):
        super().__init__()
        self.baz = True
```

### Rationale:

Used when an `__init__` method is called on a class which is not in the direct
ancestors for the analysed class.

### Related resources:

- [Testcases](https://github.com/PyCQA/pylint/blob/master/tests/input/func_w0233.py)
- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22non-parent-init-called%22+OR+%22W0233%22)
