## W0235 (useless-super-delegation)

### :x: Problematic code:

```python
class Foo:
    def __init__(self):
        print(f'{self.__class__.__name__} constructor')

class Bar(Foo):
    def __init__(self):
        super().__init__()
```

### :heavy_check_mark: Correct code:

```python
class Foo:
    def __init__(self):
        print(f'{self.__class__.__name__} constructor')

class Bar(Foo):
    pass
```

### Rationale:

Used whenever we can detect that an overridden method is useless, relying on
`super()` delegation to do the same thing as another method from the MRO.

### Related resources:

- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22useless-super-delegation%22+OR+%22W0235%22)
