## E0703 (bad-exception-context)

### :x: Problematic code:

```python
def foo(x, y):
    try:
        return x / y
    except int as e:
        raise ZeroDivisionError from e
```

### :heavy_check_mark: Correct code:

```python
def foo(x, y):
    try:
        return x / y
    except ZeroDivisionError as e:
        raise ValueError from e
```

### Rationale:

Used when using the syntax `raise ... from ...`, where the exception context
is not an exception, nor None. This message belongs to the exceptions
checker.

### Related resources:

- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22bad-exception-context%22+OR+%22E0703%22)
