## E0704 (misplaced-bare-raise)

### :x: Problematic code:

```python
def foo(x):
    if x <= 10:
        raise
```

### :heavy_check_mark: Correct code:

```python
def foo(x):
    if x <= 10:
        raise ValueError('x should be equal or grater than 10.')
```

### Rationale:

Used when a bare raise is not used inside an except clause. This generates an
error, since there are no active exceptions to be reraised. An exception to
this rule is represented by a bare raise inside a finally clause, which might
work, as long as an exception is raised inside the try block, but it is
nevertheless a code smell that must not be relied upon.

### Related resources:

- [Testcases](#)
- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22misplaced-bare-raise%22+OR+%22E0704%22)
