## C0411 (wrong-import-order)

### :x: Problematic code:

```python
from django.conf import settings

import os

from app.forms import MyForm
```

### :heavy_check_mark: Correct code:

```python
import os

from django.conf import settings

from app.forms import MyForm
```

### Rationale:

Used when PEP8 import order is not respected (standard imports first, then
third-party libraries, then local imports).

### Related resources:

- [A handy tool for Python imports (isort)](https://github.com/timothycrosley/isort)
- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22wrong-import-order%22+OR+%22C0411%22)
