## R0401 (cyclic-import)

### :x: Problematic code:

```python
cat > a.py <<EOF
import b
EOF

cat > b.py <<EOF
import a
EOF
```

### :heavy_check_mark: Correct code:

```python
cat > intermediate.py <<EOF
import a
import b

# do some actions with `a` and `b` modules
EOF

cat > a.py <<EOF
# do some action
EOF

cat > b.py <<EOF
# do some action
EOF
```

### Rationale:

Used when a cyclic import between two or more modules is detected. 

### Related resources:

- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22cyclic-import%22+OR+%22R0401%22)
