## W1201 (logging-not-lazy)

### :x: Problematic code:

```python
import logging

logging.basicConfig(level=logging.INFO)
logging.info('Test %s' % 'case')
```

### :heavy_check_mark: Correct code:

```python
import logging

logging.basicConfig(level=logging.INFO)
logging.info('Test %s', 'case')
```

### Rationale:

Used when a logging statement has a call form of
`logging.<logging method>(format_string % (format_args...))`.
Use another type of string formatting instead. You can use `%` formatting
but leave interpolation to the logging function by passing the parameters
as arguments. If logging-fstring-interpolation is disabled then you can use
fstring formatting. If logging-format-interpolation is disabled then you can
use `str.format`.

### Related resources:

- [Testcases](https://github.com/PyCQA/pylint/blob/master/tests/message/unittest_message_definition_store.py)
- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22logging-not-lazy%22+OR+%22W1201%22)
