## W1202 (logging-format-interpolation)

### :x: Problematic code:

```python
import logging

logging.basicConfig(level=logging.INFO)
logging.info('Test {}'.format(case))
```

### :heavy_check_mark: Correct code:

```python
import logging

logging.basicConfig(level=logging.INFO)
logging.info('Test %s', 'case')
```

### Rationale:

Used when a logging statement has a call form of
`logging.<logging method>(format_string.format(format_args...))`.
Use another type of string formatting instead. You can use `%` formatting
but leave interpolation to the logging function by passing the parameters
as arguments. If logging-fstring-interpolation is disabled then you can use
fstring formatting. If logging-not-lazy is disabled then you can use `%`
formatting as normal.

### Related resources:

- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22logging-format-interpolation%22+OR+%22W1202%22)
