## R1705 (no-else-return)

### :x: Problematic code:

```python
def foo(x):
    if x:
        return 1
    else:
        return 2
```

### :heavy_check_mark: Correct code:

```python
def foo(x):
    if x:
        return 1
    return 2
```

### Rationale:

Unnecessary `else` after `return`.

Used in order to highlight an unnecessary block of code following an if
containing a `return` statement. As such, it will warn when it encounters an
`else` following a chain of ifs, all of them containing a `return` statement.

### Related resources:

- [Testcases](https://github.com/PyCQA/pylint/blob/master/tests/functional/n/no_else_return.py)
- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22no-else-return%22+OR+%22R1705%22)
- [StackOverflow](https://stackoverflow.com/questions/9191388/it-is-more-efficient-to-use-if-return-return-or-if-else-return) (It is more efficient to use if-return-return or if-else-return?)