## R1708 (stop-iteration-return)

### :x: Problematic code:

```python
def foo(n):
    for i, num in enumerate(range(n)):
        yield i, num

    raise StopIteration
```

### :heavy_check_mark: Correct code:

```python
def foo(n):
    for i, num in enumerate(range(n)):
        yield i, num

    return
```

### Rationale:

According to PEP479, the raise of `StopIteration` to end the loop of a
generator may lead to hard to find bugs. This PEP specify that raise
`StopIteration` has to be replaced by a simple `return` statement.

### Related resources:

- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22stop-iteration-return%22+OR+%22R1708%22)
