## R1710 (inconsistent-return-statements)

### :x: Problematic code:

```python
def foo(x):
    if x:
        return 1
```

### :heavy_check_mark: Correct code:

```python
def foo(x):
    if x:
        return 1

    return None
```

### Rationale:

Either all `return` statements in a function should `return` an expression, 
or none of them should. According to **`PEP8`**, if any `return` statement
returns an expression, any `return` statements where no value is returned
should explicitly state this as `return None`, and an explicit `return`
statement should be present at the end of the function (if reachable).

### Related resources:

- [Testcases](https://github.com/PyCQA/pylint/blob/master/tests/functional/i/inconsistent_returns.py)
- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22inconsistent-return-statements%22+OR+%22R1710%22)