## R1720 (no-else-raise)

### :x: Problematic code:

```python
def foo(n: int, stop: int):
    for i in range(n):
        if i == stop:
            raise ValueError
        else:
            yield i
```

### :heavy_check_mark: Correct code:

```python
def foo(n: int, stop: int):
    for i in range(n):
        if i == stop:
            raise ValueError

        yield i
```

### Rationale:

Used in order to highlight an unnecessary block of code following an `if`
containing a `raise` statement. As such, it will warn when it encounters an
`else` following a chain of `if`s, all of them containing a `raise` statement.

### Related resources:

- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22no-else-raise%22+OR+%22R1720%22)
