## R1723 (no-else-break)

### :x: Problematic code:

```python
def foo(n: int, stop: int):
    for i in range(n):
        if i == stop:
            break
        else:
            yield i
```

### :heavy_check_mark: Correct code:

```python
def foo(n: int, stop: int):
    for i in range(n):
        if i == stop:
            break

        yield i
```

### Rationale:

Used in order to highlight an unnecessary block of code following an `if`
containing a `break` statement. As such, it will warn when it encounters an
`else` following a chain of `if`s, all of them containing a `break` statement.

### Related resources:

- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22no-else-break%22+OR+%22R1723%22)
