## R1724 (no-else-continue)

### :x: Problematic code:

```python
def foo(n: int, stop: int):
    for i in range(n):
        if i == stop:
            continue
        else:
            yield i
```

### :heavy_check_mark: Correct code:

```python
def foo(n: int, stop: int):
    for i in range(n):
        if i == stop:
            continue

        yield i
```

### Rationale:

Used in order to highlight an unnecessary block of code following an `if`
containing a `continue` statement. As such, it will warn when it encounters an
`else` following a chain of `if`s, all of them containing a `continue`
statement.

### Related resources:

- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22no-else-continue%22+OR+%22R1724%22)
