## W1501 (bad-open-mode)

### :x: Problematic code:

```python
def foo(file_path):
    with open(file_path, 'z') as fh:
        contents = fh.read()

    return contents
```

### :heavy_check_mark: Correct code:

```python
def foo(file_path):
    with open(file_path, 'r') as fh:
        contents = fh.read()

    return contents
```

### Rationale:

Python supports `r`, `w`, `a[, x]` modes with `b,` `+,` and `U `(only with 
`r)` options.

### Related resources:

- [`open` documentation](http://docs.python.org/3/library/functions.html#open)
- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22bad-open-mode%22+OR+%22W1501%22)
