## W1503 (redundant-unittest-assert)

### :x: Problematic code:

```python
import unittest


class DummyTestCase(unittest.TestCase):
    def test_dummy(self):
        value = 'foo'

        self.assertTrue(bool(value) is True)
```

### :heavy_check_mark: Correct code:

```python
import unittest


class DummyTestCase(unittest.TestCase):
    def test_dummy(self):
        value = 'foo'

        self.assertTrue(value)
```

### Rationale:

The first argument of `assertTrue` and `assertFalse` is a condition. If a
constant is passed as parameter, that condition will be always true. In this
case a warning should be emitted.

### Related resources:

- [`unittest` package](https://docs.python.org/3/library/unittest.html)
- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22redundant-unittest-assert%22+OR+%22W1503%22)
