## W1506 (bad-thread-instantiation)

### :x: Problematic code:

```python
import threading


def thread_target(n):
    print(n ** 2)


thread = threading.Thread(thread_target, args=(10,))
thread.start()

```

### :heavy_check_mark: Correct code:

```python
import threading


def thread_target(n):
    print(n ** 2)


thread = threading.Thread(target=thread_target, args=(10,))
thread.start()
```

### Rationale:

The warning is emitted when a `threading.Thread` class is instantiated without
the target function being passed. By default, the first parameter is the
`group` param, not the `target` param.

### Related resources:

- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22bad-thread-instantiation%22+OR+%22W1506%22)
