## W1507 (shallow-copy-environ)

### :x: Problematic code:

```python
import copy
import os

envs = copy.copy(os.environ)
```

### :heavy_check_mark: Correct code:

```python
import os

envs = os.environ.copy()
```

### Rationale:

`os.environ` is not a `dict` object but proxy object, so shallow copy has still
effects on original object. See https://bugs.python.org/issue15373 for
reference.

### Related resources:

- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22shallow-copy-environ%22+OR+%22W1507%22)
