## W1510 (subprocess-run-check)

### :x: Problematic code:

```python
import subprocess

proc = subprocess.run(['ls', '-l', '/dev/null'], capture_output=True)
```

### :heavy_check_mark: Correct code:

```python
import subprocess

proc = subprocess.run(['ls', '-l', '/dev/null'], capture_output=True, check=True)
```

### Rationale:

The check parameter should always be used with explicitly set `check` keyword
to make clear what the error-handling behavior
is.

### Related resources:

- [`subprocess.run` documentation](https//docs.python.org/3/library/subprocess.html#subprocess.run)
- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22subprocess-run-check%22+OR+%22W1510%22)
