## E1129 (not-context-manager)

### :x: Problematic code:

```python
class Ctx:
    def __enter__(self):
        pass


with Ctx() as ctx:
    pass
```

### :heavy_check_mark: Correct code:

```python
class Ctx:
    def __enter__(self):
        pass

    def __exit__(self, *exc):
        pass


with Ctx() as ctx:
    pass
```

### Rationale:

Used when an instance in a with statement doesn't implement the context
manager protocol(`__enter__`/`__exit__`).

### Related resources:

- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22not-context-manager%22+OR+%22E1129%22)
