## E1137 (unsupported-assignment-operation)

### :x: Problematic code:

```python
class Foo:
    def __init__(self, numbers):
        self.numbers = numbers

    def __getitem__(self, value):
        return self.numbers[value]


foo = Foo([1, 2, 3])
foo[0] = 0
print(foo[0])
```

### :heavy_check_mark: Correct code:

```python
class Foo:
    def __init__(self, numbers):
        self.numbers = numbers

    def __getitem__(self, value):
        return self.numbers[value]

    def __setitem__(self, index, value):
        self.numbers[index] = value


foo = Foo([1, 2, 3])
foo[0] = 0
print(foo[0])
```

### Rationale:

Emitted when an object does not support item assignment (i.e. doesn't define
`__setitem__` method).

### Related resources:

- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22unsupported-assignment-operation%22+OR+%22E1137%22)
