## E1138 (unsupported-delete-operation)

### :x: Problematic code:

```python
class Foo:
    def __init__(self, numbers):
        self.numbers = numbers

foo = Foo([1, 2, 3])
del foo[0]
print(foo.numbers)
```

### :heavy_check_mark: Correct code:

```python
class Foo:
    def __init__(self, numbers):
        self.numbers = numbers

    def __delitem__(self, index):
        self.numbers.pop(index)

foo = Foo([1, 2, 3])
del foo[0]
print(foo.numbers)
```

### Rationale:

Emitted when an object does not support item deletion (i.e. doesn't define
`__delitem__` method).

### Related resources:

- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22unsupported-delete-operation%22+OR+%22E1138%22)
