## E0633 (unpacking-non-sequence)

### :x: Problematic code:

```python
class Foo:
    def __init__(self, numbers):
        self.numbers = numbers


foo = Foo([1, 2, 3])
a, b, c = foo
print(a, b, c)
```

### :heavy_check_mark: Correct code:

```python
class Foo:
    def __init__(self, numbers):
        self.numbers = numbers

    def __iter__(self):
        return iter(self.numbers)


foo = Foo([1, 2, 3])
a, b, c = foo
print(a, b, c)
```

### Rationale:

Used when something which is not a sequence is used in an unpack assignment

### Related resources:

- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22unpacking-non-sequence%22+OR+%22E0633%22)
