## W0611 (unused-import)

### :x: Problematic code:

```python
from functools import lru_cache, reduce


def foo(data):
    return reduce(lambda x, y: x + y, data)


print(foo([1, 2, 3, 4]))
```

### :heavy_check_mark: Correct code:

```python
from functools import lru_cache, reduce


@lru_cache(maxsize=32)
def foo(data):
    return reduce(lambda x, y: x + y, data)


print(foo([1, 2, 3, 4]))
```

### Rationale:

Used when an imported module or variable is not used.

### Related resources:

- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22unused-import%22+OR+%22W0611%22)
