## W0631 (undefined-loop-variable)

### :x: Problematic code:

```python
data = {'x': 1, 'y': 2, 'z': 3}
for k, v in data.items():
    x = f'key: {k} => value: {v}'
    break

print(x)
```

### :heavy_check_mark: Correct code:

```python
data = {'x': 1, 'y': 2, 'z': 3}
x = None
for k, v in data.items():
    x = f'key: {k} => value: {v}'
    break

print(x)
```

### Rationale:

Used when a loop variable (i.e. defined by a for loop or a list comprehension
or a generator expression) is used outside the loop.

### Related resources:

- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22undefined-loop-variable%22+OR+%22W0631%22)
