## W0640 (cell-var-from-loop)

### :x: Problematic code:

```python
def foo(numbers):
    for i in numbers:
        def bar():
            print(i)
        bar()
```

### :heavy_check_mark: Correct code:

```python
def bar(x):
    print(x)



def foo(numbers):
    for i in numbers:
        bar(i)
```

### Rationale:

A variable used in a closure is defined in a loop. This will result in all
closures using the same value for the closed-over variable.

### Related resources:

- [Testcases](https://github.com/PyCQA/pylint/blob/master/tests/functional/n/nested_func_defined_in_loop.py)
- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22cell-var-from-loop%22+OR+%22W0640%22)
